<?php

namespace Slovocast\Controller\Channel;

use Odan\Session\SessionInterface;
use Psr\Log\LoggerInterface;
use Slovocast\Controller\Controller;
use Psr\Http\Message\ResponseInterface as Response;
use Slovocast\Domain\Repository\Channel\ChannelRepositoryInterface;
use Slovocast\Domain\Entity\Channel;
use Slovocast\Domain\Entity\User;

class CreateChannelAction extends Controller
{
    public function __construct(
        protected SessionInterface $session,
        protected LoggerInterface $logger,
        protected ChannelRepositoryInterface $channelRepository
    ) { }

    public function handle(): Response
    {
        $userData = $this->session->get('user');
        $formData = $this->request->getParsedBody();

        if ($userData['id'] !== $formData['user_id']) {
            $this->session->getFlash()->add("error", "Unable to create channel.");
            $this->logger->error("Session User ID and Form User ID do no match.");
            return $this->render('channel/create.twig')->withStatus(400);
        }

        $formData['explicit'] = $formData['explicit'] === "yes" ? true : false;

        $user = User::fromArray($userData);
        $channel = Channel::fromArray($formData);

        /**
         * Should wrap this in a try/catch probably
         */
        if (!$this->channelRepository->create($channel, $user)) {
            return $this->render('channel/create.twig')->withStatus(500);
        }

        $this->session->getFlash()->add("success", "Successfully created new channel.");
    }
}
